%% Conjugate Gradients Algorithm
%% Input:
%%	fun - function handler of function to minimize
%%	dfun - gradient of function
%%	x0 - first guess of solution
%%	eps - accuracy. By default is 0.01
%% Output:
%%	y - function minimizer coordinates
function y=CG(fun, dfun, x0, eps=0.01)
	xi = x0; %% initialize the iterative
	di = -dfun(x0); %% "direction" of negative gradient
	while (norm(di) > eps) %% we stopp, if gradient is smaller eps
		tau = LS(fun, di, xi); %% Line Search to choose step length
		xj = xi+tau*di;
		omega=norm(dfun(xj))^2/norm(dfun(xi))^2;
		xi=xj; %% update iterative
		di = -dfun(xi)+omega*di; %% update "direction"
	endwhile
	y=xi; %% save results
